Cumin |release| documentation
=============================

An automation and orchestration framework written in Python.

.. toctree::
   :maxdepth: 3

   introduction
   installation
   configuration
   cli
   api/index
   development

.. toctree::
   :maxdepth: 2

   release


Indices and tables
------------------

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
